Learn R Programming

healthbR (version 0.2.0)

cnes_dictionary: CNES Data Dictionary

Description

Returns a tibble with the complete data dictionary for the CNES, including variable descriptions and category labels.

Usage

cnes_dictionary(variable = NULL)

Value

A tibble with columns: variable, description, code, label.

Arguments

variable

Character. If provided, returns dictionary for a specific variable only. Default: NULL (returns all variables).

See Also

Other cnes: cnes_cache_status(), cnes_clear_cache(), cnes_data(), cnes_info(), cnes_variables(), cnes_years()

Examples

Run this code
cnes_dictionary()
cnes_dictionary("TP_UNID")
cnes_dictionary("ESFERA_A")

Run the code above in your browser using DataLab