Learn R Programming

healthbR (version 0.2.0)

cnes_variables: List CNES Variables

Description

Returns a tibble with available variables in the CNES data (ST type), including descriptions and value types.

Usage

cnes_variables(type = "ST", search = NULL)

Value

A tibble with columns: variable, description, type, section.

Arguments

type

Character. File type to show variables for. Currently only "ST" is fully documented. Default: "ST".

search

Character. Optional search term to filter variables by name or description. Case-insensitive and accent-insensitive.

See Also

Other cnes: cnes_cache_status(), cnes_clear_cache(), cnes_data(), cnes_dictionary(), cnes_info(), cnes_years()

Examples

Run this code
cnes_variables()
cnes_variables(search = "tipo")
cnes_variables(search = "gestao")

Run the code above in your browser using DataLab