Learn R Programming

healthbR (version 0.2.0)

pnadc_modules: List available PNADC modules

Description

Returns information about the available supplementary modules in PNAD Continua that are supported by this package.

Usage

pnadc_modules()

Arguments

Value

A tibble with module information including name, available years, and descriptions.

Examples

Run this code
pnadc_modules()

Run the code above in your browser using DataLab