Learn R Programming

healthbR (version 0.2.0)

sia_dictionary: SIA Data Dictionary

Description

Returns a tibble with the complete data dictionary for the SIA, including variable descriptions and category labels.

Usage

sia_dictionary(variable = NULL)

Value

A tibble with columns: variable, description, code, label.

Arguments

variable

Character. If provided, returns dictionary for a specific variable only. Default: NULL (returns all variables).

See Also

Other sia: sia_cache_status(), sia_clear_cache(), sia_data(), sia_info(), sia_variables(), sia_years()

Examples

Run this code
sia_dictionary()
sia_dictionary("PA_SEXO")
sia_dictionary("PA_RACACOR")

Run the code above in your browser using DataLab