Learn R Programming

healthbR (version 0.2.0)

sih_dictionary: SIH Data Dictionary

Description

Returns a tibble with the complete data dictionary for the SIH, including variable descriptions and category labels.

Usage

sih_dictionary(variable = NULL)

Value

A tibble with columns: variable, description, code, label.

Arguments

variable

Character. If provided, returns dictionary for a specific variable only. Default: NULL (returns all variables).

See Also

Other sih: sih_cache_status(), sih_clear_cache(), sih_data(), sih_info(), sih_variables(), sih_years()

Examples

Run this code
sih_dictionary()
sih_dictionary("SEXO")
sih_dictionary("CAR_INT")

Run the code above in your browser using DataLab