Learn R Programming

healthbR (version 0.2.0)

sim_dictionary: SIM Data Dictionary

Description

Returns a tibble with the complete data dictionary for the SIM, including variable descriptions and category labels.

Usage

sim_dictionary(variable = NULL)

Value

A tibble with columns: variable, description, code, label.

Arguments

variable

Character. If provided, returns dictionary for a specific variable only. Default: NULL (returns all variables).

See Also

Other sim: sim_cache_status(), sim_clear_cache(), sim_data(), sim_info(), sim_variables(), sim_years()

Examples

Run this code
sim_dictionary()
sim_dictionary("SEXO")
sim_dictionary("RACACOR")

Run the code above in your browser using DataLab