Learn R Programming

healthbR (version 0.2.0)

sinan_info: SINAN Module Information

Description

Displays information about the Notifiable Diseases Information System (SINAN), including data sources, available years, diseases, and usage guidance.

Usage

sinan_info()

Arguments

Value

A list with module information (invisibly).

See Also

Other sinan: sinan_cache_status(), sinan_clear_cache(), sinan_data(), sinan_dictionary(), sinan_diseases(), sinan_variables(), sinan_years()

Examples

Run this code
sinan_info()

Run the code above in your browser using DataLab