Learn R Programming

healthbR (version 0.2.0)

sinasc_dictionary: SINASC Data Dictionary

Description

Returns a tibble with the complete data dictionary for the SINASC, including variable descriptions and category labels.

Usage

sinasc_dictionary(variable = NULL)

Value

A tibble with columns: variable, description, code, label.

Arguments

variable

Character. If provided, returns dictionary for a specific variable only. Default: NULL (returns all variables).

See Also

Other sinasc: sinasc_cache_status(), sinasc_clear_cache(), sinasc_data(), sinasc_info(), sinasc_variables(), sinasc_years()

Examples

Run this code
sinasc_dictionary()
sinasc_dictionary("SEXO")
sinasc_dictionary("PARTO")

Run the code above in your browser using DataLab