Learn R Programming

healthbR (version 0.2.0)

sinasc_variables: List SINASC Variables

Description

Returns a tibble with available variables in the SINASC microdata, including descriptions and value types.

Usage

sinasc_variables(year = NULL, search = NULL)

Value

A tibble with columns: variable, description, type, section.

Arguments

year

Integer. If provided, returns variables available for that specific year (reserved for future use). Default: NULL.

search

Character. Optional search term to filter variables by name or description. Case-insensitive.

See Also

Other sinasc: sinasc_cache_status(), sinasc_clear_cache(), sinasc_data(), sinasc_dictionary(), sinasc_info(), sinasc_years()

Examples

Run this code
sinasc_variables()
sinasc_variables(search = "mae")
sinasc_variables(search = "parto")

Run the code above in your browser using DataLab