Learn R Programming

healthbR (version 0.2.0)

sipni_info: SI-PNI Module Information

Description

Displays information about the National Immunization Program Information System (SI-PNI), including data sources, available years, file types, and usage guidance.

Usage

sipni_info()

Arguments

Value

A list with module information (invisibly).

See Also

Other sipni: sipni_cache_status(), sipni_clear_cache(), sipni_data(), sipni_dictionary(), sipni_variables(), sipni_years()

Examples

Run this code
sipni_info()

Run the code above in your browser using DataLab