Learn R Programming

healthbR (version 0.2.0)

sisab_variables: List SISAB Variables

Description

Returns a tibble with available variables in the SISAB coverage data, including descriptions and value types.

Usage

sisab_variables(type = "aps", search = NULL)

Value

A tibble with columns: variable, description, type, section.

Arguments

type

Character. Report type to show variables for. "aps" (default), "sb", "acs", or "pns".

search

Character. Optional search term to filter variables by name or description. Case-insensitive and accent-insensitive.

See Also

Other sisab: sisab_cache_status(), sisab_clear_cache(), sisab_data(), sisab_info(), sisab_years()

Examples

Run this code
sisab_variables()
sisab_variables(type = "sb")
sisab_variables(search = "cobertura")

Run the code above in your browser using DataLab