Learn R Programming

healthbR (version 0.1.1)

vigitel_excel_path: Get path to Excel file for a specific year

Description

Get path to Excel file for a specific year

Usage

vigitel_excel_path(year, cache_dir = NULL)

Value

Path to excel file

Arguments

year

Integer year

cache_dir

Optional custom cache directory