vigitel_parquet_path: Get path to Parquet file for a specific year
Description
Get path to Parquet file for a specific year
Usage
vigitel_parquet_path(year, cache_dir = NULL)
Value
Path to parquet file
Arguments
- year
Integer year
- cache_dir
Optional custom cache directory