Learn R Programming

healthbR (version 0.2.0)

ans_variables: List ANS Variables

Description

Returns a tibble with available variables in the ANS data, including descriptions and value types.

Usage

ans_variables(type = "beneficiaries", search = NULL)

Value

A tibble with columns: variable, description, type, section.

Arguments

type

Character. Type of data. One of "beneficiaries" (default), "complaints", "financial", or "operators".

search

Character. Optional search term to filter variables by name or description. Case-insensitive and accent-insensitive.

See Also

Other ans: ans_cache_status(), ans_clear_cache(), ans_data(), ans_info(), ans_operators(), ans_years()

Examples

Run this code
ans_variables()
ans_variables(type = "complaints")
ans_variables(search = "operadora")

Run the code above in your browser using DataLab