powered by
Returns a tibble with available variables in the ANS data, including descriptions and value types.
ans_variables(type = "beneficiaries", search = NULL)
A tibble with columns: variable, description, type, section.
Character. Type of data. One of "beneficiaries" (default), "complaints", "financial", or "operators".
"beneficiaries"
"complaints"
"financial"
"operators"
Character. Optional search term to filter variables by name or description. Case-insensitive and accent-insensitive.
Other ans: ans_cache_status(), ans_clear_cache(), ans_data(), ans_info(), ans_operators(), ans_years()
ans_cache_status()
ans_clear_cache()
ans_data()
ans_info()
ans_operators()
ans_years()
ans_variables() ans_variables(type = "complaints") ans_variables(search = "operadora")
Run the code above in your browser using DataLab