powered by
Returns a tibble with the complete data dictionary for the CNES, including variable descriptions and category labels.
cnes_dictionary(variable = NULL)
A tibble with columns: variable, description, code, label.
Character. If provided, returns dictionary for a specific variable only. Default: NULL (returns all variables).
Other cnes: cnes_cache_status(), cnes_clear_cache(), cnes_data(), cnes_info(), cnes_variables(), cnes_years()
cnes_cache_status()
cnes_clear_cache()
cnes_data()
cnes_info()
cnes_variables()
cnes_years()
cnes_dictionary() cnes_dictionary("TP_UNID") cnes_dictionary("ESFERA_A")
Run the code above in your browser using DataLab