Learn R Programming

healthbR (version 0.2.0)

cnes_info: CNES Module Information

Description

Displays information about the National Health Facility Registry (CNES), including data sources, available years, file types, and usage guidance.

Usage

cnes_info()

Arguments

Value

A list with module information (invisibly).

See Also

Other cnes: cnes_cache_status(), cnes_clear_cache(), cnes_data(), cnes_dictionary(), cnes_variables(), cnes_years()

Examples

Run this code
cnes_info()

Run the code above in your browser using DataLab