powered by
Displays information about the National Health Facility Registry (CNES), including data sources, available years, file types, and usage guidance.
cnes_info()
A list with module information (invisibly).
Other cnes: cnes_cache_status(), cnes_clear_cache(), cnes_data(), cnes_dictionary(), cnes_variables(), cnes_years()
cnes_cache_status()
cnes_clear_cache()
cnes_data()
cnes_dictionary()
cnes_variables()
cnes_years()
Run the code above in your browser using DataLab