powered by
Returns a tibble with available variables in the CNES data (ST type), including descriptions and value types.
cnes_variables(type = "ST", search = NULL)
A tibble with columns: variable, description, type, section.
Character. File type to show variables for. Currently only "ST" is fully documented. Default: "ST".
"ST"
Character. Optional search term to filter variables by name or description. Case-insensitive and accent-insensitive.
Other cnes: cnes_cache_status(), cnes_clear_cache(), cnes_data(), cnes_dictionary(), cnes_info(), cnes_years()
cnes_cache_status()
cnes_clear_cache()
cnes_data()
cnes_dictionary()
cnes_info()
cnes_years()
cnes_variables() cnes_variables(search = "tipo") cnes_variables(search = "gestao")
Run the code above in your browser using DataLab