powered by
Returns information about the available supplementary modules in PNAD Continua that are supported by this package.
pnadc_modules()
A tibble with module information including name, available years, and descriptions.
Run the code above in your browser using DataLab