powered by
Returns a tibble with the complete data dictionary for the SIA, including variable descriptions and category labels.
sia_dictionary(variable = NULL)
A tibble with columns: variable, description, code, label.
Character. If provided, returns dictionary for a specific variable only. Default: NULL (returns all variables).
Other sia: sia_cache_status(), sia_clear_cache(), sia_data(), sia_info(), sia_variables(), sia_years()
sia_cache_status()
sia_clear_cache()
sia_data()
sia_info()
sia_variables()
sia_years()
sia_dictionary() sia_dictionary("PA_SEXO") sia_dictionary("PA_RACACOR")
Run the code above in your browser using DataLab