Learn R Programming

healthbR (version 0.2.0)

sia_variables: List SIA Variables

Description

Returns a tibble with available variables in the SIA microdata (PA type), including descriptions and value types.

Usage

sia_variables(type = "PA", search = NULL)

Value

A tibble with columns: variable, description, type, section.

Arguments

type

Character. File type to show variables for. Currently only "PA" is fully documented. Default: "PA".

search

Character. Optional search term to filter variables by name or description. Case-insensitive and accent-insensitive.

See Also

Other sia: sia_cache_status(), sia_clear_cache(), sia_data(), sia_dictionary(), sia_info(), sia_years()

Examples

Run this code
sia_variables()
sia_variables(search = "sexo")
sia_variables(search = "procedimento")

Run the code above in your browser using DataLab