powered by
Returns a tibble with available variables in the SIA microdata (PA type), including descriptions and value types.
sia_variables(type = "PA", search = NULL)
A tibble with columns: variable, description, type, section.
Character. File type to show variables for. Currently only "PA" is fully documented. Default: "PA".
"PA"
Character. Optional search term to filter variables by name or description. Case-insensitive and accent-insensitive.
Other sia: sia_cache_status(), sia_clear_cache(), sia_data(), sia_dictionary(), sia_info(), sia_years()
sia_cache_status()
sia_clear_cache()
sia_data()
sia_dictionary()
sia_info()
sia_years()
sia_variables() sia_variables(search = "sexo") sia_variables(search = "procedimento")
Run the code above in your browser using DataLab