powered by
Returns a tibble with the complete data dictionary for the SIH, including variable descriptions and category labels.
sih_dictionary(variable = NULL)
A tibble with columns: variable, description, code, label.
Character. If provided, returns dictionary for a specific variable only. Default: NULL (returns all variables).
Other sih: sih_cache_status(), sih_clear_cache(), sih_data(), sih_info(), sih_variables(), sih_years()
sih_cache_status()
sih_clear_cache()
sih_data()
sih_info()
sih_variables()
sih_years()
sih_dictionary() sih_dictionary("SEXO") sih_dictionary("CAR_INT")
Run the code above in your browser using DataLab