Learn R Programming

healthbR (version 0.2.0)

sih_variables: List SIH Variables

Description

Returns a tibble with available variables in the SIH microdata, including descriptions and value types.

Usage

sih_variables(year = NULL, search = NULL)

Value

A tibble with columns: variable, description, type, section.

Arguments

year

Integer. If provided, returns variables available for that specific year (reserved for future use). Default: NULL.

search

Character. Optional search term to filter variables by name or description. Case-insensitive.

See Also

Other sih: sih_cache_status(), sih_clear_cache(), sih_data(), sih_dictionary(), sih_info(), sih_years()

Examples

Run this code
sih_variables()
sih_variables(search = "diag")
sih_variables(search = "valor")

Run the code above in your browser using DataLab