powered by
Returns a tibble with available variables in the SIH microdata, including descriptions and value types.
sih_variables(year = NULL, search = NULL)
A tibble with columns: variable, description, type, section.
Integer. If provided, returns variables available for that specific year (reserved for future use). Default: NULL.
Character. Optional search term to filter variables by name or description. Case-insensitive.
Other sih: sih_cache_status(), sih_clear_cache(), sih_data(), sih_dictionary(), sih_info(), sih_years()
sih_cache_status()
sih_clear_cache()
sih_data()
sih_dictionary()
sih_info()
sih_years()
sih_variables() sih_variables(search = "diag") sih_variables(search = "valor")
Run the code above in your browser using DataLab