powered by
Returns a tibble with the complete data dictionary for the SIM, including variable descriptions and category labels.
sim_dictionary(variable = NULL)
A tibble with columns: variable, description, code, label.
Character. If provided, returns dictionary for a specific variable only. Default: NULL (returns all variables).
Other sim: sim_cache_status(), sim_clear_cache(), sim_data(), sim_info(), sim_variables(), sim_years()
sim_cache_status()
sim_clear_cache()
sim_data()
sim_info()
sim_variables()
sim_years()
sim_dictionary() sim_dictionary("SEXO") sim_dictionary("RACACOR")
Run the code above in your browser using DataLab