Learn R Programming

healthbR (version 0.2.0)

sim_variables: List SIM Variables

Description

Returns a tibble with available variables in the SIM microdata, including descriptions and value types.

Usage

sim_variables(year = NULL, search = NULL)

Value

A tibble with columns: variable, description, type, section.

Arguments

year

Integer. If provided, returns variables available for that specific year (reserved for future use). Default: NULL.

search

Character. Optional search term to filter variables by name or description. Case-insensitive.

See Also

Other sim: sim_cache_status(), sim_clear_cache(), sim_data(), sim_dictionary(), sim_info(), sim_years()

Examples

Run this code
sim_variables()
sim_variables(search = "causa")
sim_variables(search = "mae")

Run the code above in your browser using DataLab