powered by
Returns a tibble with available variables in the SIM microdata, including descriptions and value types.
sim_variables(year = NULL, search = NULL)
A tibble with columns: variable, description, type, section.
Integer. If provided, returns variables available for that specific year (reserved for future use). Default: NULL.
Character. Optional search term to filter variables by name or description. Case-insensitive.
Other sim: sim_cache_status(), sim_clear_cache(), sim_data(), sim_dictionary(), sim_info(), sim_years()
sim_cache_status()
sim_clear_cache()
sim_data()
sim_dictionary()
sim_info()
sim_years()
sim_variables() sim_variables(search = "causa") sim_variables(search = "mae")
Run the code above in your browser using DataLab