Learn R Programming

healthbR (version 0.2.0)

sinan_dictionary: SINAN Data Dictionary

Description

Returns a tibble with the complete data dictionary for the SINAN, including variable descriptions and category labels.

Usage

sinan_dictionary(variable = NULL)

Value

A tibble with columns: variable, description, code, label.

Arguments

variable

Character. If provided, returns dictionary for a specific variable only. Default: NULL (returns all variables).

See Also

Other sinan: sinan_cache_status(), sinan_clear_cache(), sinan_data(), sinan_diseases(), sinan_info(), sinan_variables(), sinan_years()

Examples

Run this code
sinan_dictionary()
sinan_dictionary("CS_SEXO")
sinan_dictionary("EVOLUCAO")

Run the code above in your browser using DataLab