powered by
Returns a tibble with the complete data dictionary for the SINAN, including variable descriptions and category labels.
sinan_dictionary(variable = NULL)
A tibble with columns: variable, description, code, label.
Character. If provided, returns dictionary for a specific variable only. Default: NULL (returns all variables).
Other sinan: sinan_cache_status(), sinan_clear_cache(), sinan_data(), sinan_diseases(), sinan_info(), sinan_variables(), sinan_years()
sinan_cache_status()
sinan_clear_cache()
sinan_data()
sinan_diseases()
sinan_info()
sinan_variables()
sinan_years()
sinan_dictionary() sinan_dictionary("CS_SEXO") sinan_dictionary("EVOLUCAO")
Run the code above in your browser using DataLab