powered by
Displays information about the Notifiable Diseases Information System (SINAN), including data sources, available years, diseases, and usage guidance.
sinan_info()
A list with module information (invisibly).
Other sinan: sinan_cache_status(), sinan_clear_cache(), sinan_data(), sinan_dictionary(), sinan_diseases(), sinan_variables(), sinan_years()
sinan_cache_status()
sinan_clear_cache()
sinan_data()
sinan_dictionary()
sinan_diseases()
sinan_variables()
sinan_years()
Run the code above in your browser using DataLab