powered by
Returns a tibble with the complete data dictionary for the SINASC, including variable descriptions and category labels.
sinasc_dictionary(variable = NULL)
A tibble with columns: variable, description, code, label.
Character. If provided, returns dictionary for a specific variable only. Default: NULL (returns all variables).
Other sinasc: sinasc_cache_status(), sinasc_clear_cache(), sinasc_data(), sinasc_info(), sinasc_variables(), sinasc_years()
sinasc_cache_status()
sinasc_clear_cache()
sinasc_data()
sinasc_info()
sinasc_variables()
sinasc_years()
sinasc_dictionary() sinasc_dictionary("SEXO") sinasc_dictionary("PARTO")
Run the code above in your browser using DataLab