Learn R Programming

healthbR (version 0.2.0)

sisab_info: SISAB Module Information

Description

Displays information about the Primary Care Health Information System (SISAB), including data sources, available report types, and usage guidance.

Usage

sisab_info()

Arguments

Value

A list with module information (invisibly).

See Also

Other sisab: sisab_cache_status(), sisab_clear_cache(), sisab_data(), sisab_variables(), sisab_years()

Examples

Run this code
sisab_info()

Run the code above in your browser using DataLab