powered by
Displays information about the Primary Care Health Information System (SISAB), including data sources, available report types, and usage guidance.
sisab_info()
A list with module information (invisibly).
Other sisab: sisab_cache_status(), sisab_clear_cache(), sisab_data(), sisab_variables(), sisab_years()
sisab_cache_status()
sisab_clear_cache()
sisab_data()
sisab_variables()
sisab_years()
Run the code above in your browser using DataLab