powered by
Returns a tibble with available variables in the SISAB coverage data, including descriptions and value types.
sisab_variables(type = "aps", search = NULL)
A tibble with columns: variable, description, type, section.
Character. Report type to show variables for. "aps" (default), "sb", "acs", or "pns".
"aps"
"sb"
"acs"
"pns"
Character. Optional search term to filter variables by name or description. Case-insensitive and accent-insensitive.
Other sisab: sisab_cache_status(), sisab_clear_cache(), sisab_data(), sisab_info(), sisab_years()
sisab_cache_status()
sisab_clear_cache()
sisab_data()
sisab_info()
sisab_years()
sisab_variables() sisab_variables(type = "sb") sisab_variables(search = "cobertura")
Run the code above in your browser using DataLab