Learn R Programming

healthbR (version 0.2.0)

sisab_years: List Available SISAB Years

Description

Returns an integer vector with years for which SISAB coverage data are potentially available from the relatorioaps API. Actual availability depends on the report type.

Usage

sisab_years()

Arguments

Value

An integer vector of available years.

Details

Availability by report type:

  • aps: APS coverage (2019--present)

  • sb: Oral health coverage (2024--present)

  • acs: Community health agents (2007--present)

  • pns: PNS coverage (2020--2023)

See Also

Other sisab: sisab_cache_status(), sisab_clear_cache(), sisab_data(), sisab_info(), sisab_variables()

Examples

Run this code
sisab_years()

Run the code above in your browser using DataLab